package com.landray.kmss.sys.attachment.integrate.yozo;

import com.landray.kmss.sys.attachment.thirdSfs.vo.ThirdSfsResponseResult;
import java.util.Map;
import com.landray.kmss.sys.attachment.thirdSfs.util.SysAttThirdProxyUtil;
import com.landray.kmss.sys.filestore.util.YozoConvertConstantUtil;
import java.util.HashMap;
import com.landray.kmss.sys.filestore.scheduler.third.yozo.service.IYozoConvertFile;
import com.landray.kmss.util.UserUtil;
import com.landray.kmss.sys.filestore.util.FileStoreConvertUtil;
import com.landray.kmss.sys.attachment.thirdSfs.constant.ThirdSfsYozoContant;
import com.landray.kmss.sys.attachment.util.SysAttConfigUtil;
import com.alibaba.fastjson.JSONObject;
import com.landray.kmss.sys.attachment.integrate.yozo.interfaces.ISysAttachmentYozoProvider;
import com.landray.kmss.sys.attachment.model.SysAttMain;
import javax.servlet.http.HttpServletRequest;
import com.landray.kmss.util.SpringBeanUtil;
import com.landray.kmss.sys.attachment.service.ISysAttMainCoreInnerService;
import org.slf4j.LoggerFactory;
import org.slf4j.Logger;

public class SysAttYozoUtil
{
    private static final Logger logger;
    
    static {
        logger = LoggerFactory.getLogger(SysAttYozoUtil.class);
    }
    
    private static ISysAttMainCoreInnerService getSysAttMainCoreInnerServiceImp() {
        return (ISysAttMainCoreInnerService)SpringBeanUtil.getBean("sysAttMainService");
    }
    
    public static String getYozowoEditUrl(final HttpServletRequest request) {
        final String fdAttMainId = request.getParameter("fdAttMainId");
        SysAttMain sysAttMain = null;
        try {
            if (fdAttMainId == null || fdAttMainId.isEmpty()) {
                SysAttYozoUtil.logger.warn("fdAttMainId为空");
                return null;
            }
            sysAttMain = (SysAttMain)getSysAttMainCoreInnerServiceImp().findByPrimaryKey(fdAttMainId);
        }
        catch (final Exception e) {
            SysAttYozoUtil.logger.error("获取附件信息失败fdAttMainId={}", fdAttMainId, e);
        }
        if (sysAttMain == null) {
            SysAttYozoUtil.logger.warn("附件信息不存在，fdAttMainId={}", fdAttMainId);
            return null;
        }
        request.getParameter("canPrint");
        request.getParameter("canExport");
        final ISysAttachmentYozoProvider yozoProvider = (ISysAttachmentYozoProvider)SpringBeanUtil.getBean("YozoProviderImpl");
        final JSONObject params = new JSONObject();
        params.put("fdAttMainId", (Object)fdAttMainId);
        params.put("filename", (Object)sysAttMain.getFdFileName());
        final JSONObject json = new JSONObject();
        if (SysAttYozoUtil.logger.isDebugEnabled()) {
            SysAttYozoUtil.logger.debug("yozoProvider.getEditOnlineUrl--params={}", params);
        }
        final String url = yozoProvider.getEditOnlineUrl(params);
        json.put("url", (Object)url);
        return json.toJSONString();
    }
    
    public static String saveYozowoEdit(final HttpServletRequest request) {
        final String fdAttMainId = request.getParameter("fdAttMainId");
        SysAttMain sysAttMain = null;
        try {
            if (fdAttMainId == null || fdAttMainId.isEmpty()) {
                SysAttYozoUtil.logger.warn("fdAttMainId为空");
                return null;
            }
            sysAttMain = (SysAttMain)getSysAttMainCoreInnerServiceImp().findByPrimaryKey(fdAttMainId);
        }
        catch (final Exception e) {
            SysAttYozoUtil.logger.error("获取附件信息失败fdAttMainId={}", fdAttMainId, e);
        }
        if (sysAttMain == null) {
            SysAttYozoUtil.logger.warn("附件信息不存在，fdAttMainId={}", fdAttMainId);
            return null;
        }
        final ISysAttachmentYozoProvider yozoProvider = (ISysAttachmentYozoProvider)SpringBeanUtil.getBean("YozoProviderImpl");
        final JSONObject params = new JSONObject();
        params.put("fdAttMainId", (Object)fdAttMainId);
        final JSONObject json = new JSONObject();
        if (SysAttYozoUtil.logger.isDebugEnabled()) {
            SysAttYozoUtil.logger.debug("yozoProvider.saveYozowoEdit--params={}", params);
        }
        final String result = yozoProvider.saveEditOnline(params);
        json.put("result", (Object)result);
        return json.toJSONString();
    }
    
    public static String wrapHeader(final String fdAttMainId, final String redTempAttId, final String redTempAttName, final String bookmarkName) throws Exception {
        final ISysAttachmentYozoProvider sysAttachmentYozoProvider = (ISysAttachmentYozoProvider)SpringBeanUtil.getBean("YozoProviderImpl");
        if (sysAttachmentYozoProvider != null) {
            final JSONObject param = new JSONObject();
            param.put("fdAttMainId", (Object)fdAttMainId);
            param.put("redTempAttId", (Object)redTempAttId);
            param.put("redTempAttName", (Object)redTempAttName);
            param.put("bookmarkName", (Object)bookmarkName);
            return sysAttachmentYozoProvider.wrapHeader(param);
        }
        return null;
    }
    
    public static Boolean isEnable() throws Exception {
        Boolean flag = false;
        if ("5".equals(SysAttConfigUtil.getOnlineToolType())) {
            flag = "true".equals(ThirdSfsYozoContant.getYozoEditEnabled());
        }
        return flag;
    }
    
    public static Boolean isYozowoEnableMobile(final boolean isMobile) throws Exception {
        Boolean flag = false;
        if (isMobile && isEnable()) {
            flag = "5".equals(SysAttConfigUtil.getConfigInfo("onlineMobileToolTypeFive"));
        }
        return flag;
    }
    
    public static Boolean isYozodcsEnable() throws Exception {
        Boolean flag = false;
        if ("7".equals(SysAttConfigUtil.getReadOLConfig())) {
            flag = FileStoreConvertUtil.isOpenYozoDCSConverter(Boolean.valueOf(true));
        }
        return flag;
    }
    
    public static void setIsAtt(final HttpServletRequest request, final SysAttMain sysAttMain) {
        boolean canPrint = false;
        canPrint = UserUtil.checkAuthentication("/sys/attachment/sys_att_main/sysAttMain.do?method=print&fdId=" + sysAttMain.getFdId(), "GET");
        request.setAttribute("canPrint", (Object)canPrint);
    }
    
    public static String getYozoPreviewUrl(final HttpServletRequest request, final String fdAttMainId) throws Exception {
        final String canPrint = request.getParameter("canPrint");
        final String showRevisions = request.getParameter("showRevisions");
        final SysAttMain sysAttMain = (SysAttMain)((ISysAttMainCoreInnerService)SpringBeanUtil.getBean("sysAttMainService")).findByPrimaryKey(fdAttMainId);
        final IYozoConvertFile yozoConvertFile = (IYozoConvertFile)SpringBeanUtil.getBean("yozoConvertFile");
        final String fileName_yozo = sysAttMain.getFdFileName();
        final String fileExName = fileName_yozo.substring(fileName_yozo.lastIndexOf("."));
        final Map<String, Object> addtionInfos = new HashMap<String, Object>();
        addtionInfos.put("isPrint", "true".equals(canPrint) ? "true" : "false");
        addtionInfos.put("showRevisions", "true".equals(showRevisions) ? "true" : "false");
        final JSONObject params = new JSONObject();
        params.put("fdAttMainName", (Object)sysAttMain.getFdFileName());
        params.put("fdAttMainId", (Object)sysAttMain.getFdId());
        params.put("ConvertKey", (Object)YozoConvertConstantUtil.getPreviewConvertType(fileExName));
        params.put("addtionInfos", (Object)addtionInfos);
        params.put("curIp", (Object)request.getRemoteAddr());
        final JSONObject _rtn = SysAttThirdProxyUtil.getViewUrl("yozo", params).getData();
        final String yozoPreviewUrl = _rtn.getString("url");
        if (SysAttYozoUtil.logger.isDebugEnabled()) {
            SysAttYozoUtil.logger.debug("获取永中文件预览链接， fdAttMainId = {}, yozoPreviewUrl = {}", fdAttMainId, yozoPreviewUrl);
        }
        return yozoPreviewUrl;
    }
    
    public static void checkEditCache(final String fdAttId) {
        final JSONObject ob = new JSONObject();
        ob.put("fdAttMainId", (Object)fdAttId);
        try {
            boolean isExe = true;
            int _exCount = 0;
            while (isExe) {
                if (_exCount >= 6) {
                    break;
                }
                ++_exCount;
                final ThirdSfsResponseResult res = SysAttThirdProxyUtil.modifyAndSave("yozo", ob);
                if (res.getData() != null && "true".equals(res.getData().getString("res"))) {
                    Thread.sleep(500L);
                }
                else {
                    isExe = false;
                }
            }
        }
        catch (final Exception e) {
            SysAttYozoUtil.logger.info("获取永中编辑回调缓存出错:" + e);
        }
    }
}
